# This allows us to use these functions without attaching the packages they come from.

#' @importFrom magrittr %>%
#' @export
magrittr::`%>%`

#' @importFrom mosaicCore makeFun
#' @export
mosaicCore::makeFun

#' @importFrom mosaicCore df_stats
#' @export
mosaicCore::df_stats

#' @importFrom mosaicCore na.warn
#' @export
mosaicCore::na.warn

#' @importFrom ggforce stat_sina StatSina
#' @export
ggforce::stat_sina
#' @export
ggforce::StatSina

#' @importFrom ggforce geom_sina
#' @export
ggforce::geom_sina
